@@ -167,7 +167,7 @@ def has_equal_ast(state, incorrect_msg=None, code=None, exact=True, append=None)
     ):  # if not specified, set to False if incorrect_msg was manually specified
         append = incorrect_msg is None
     if incorrect_msg is None:
-        incorrect_msg = "Expected `{{sol_str}}`, but got `{{stu_str}}`."
+        incorrect_msg = "Ожидалось `{{sol_str}}`, но было получено `{{stu_str}}`."
 
     def parse_tree(tree):
         # get contents of module.body if only 1 element
